//===-- BuiltinsHexagon.def - Hexagon Builtin function database --*- C++ -*-==//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the Hexagon-specific builtin function database. Users of
// this file must define the BUILTIN macro to make use of this information.
//
//===----------------------------------------------------------------------===//

// The format of this database matches clang/Basic/Builtins.def.

// The builtins below are not autogenerated from iset.py.
// Make sure you do not overwrite these.

BUILTIN(__builtin_brev_ldd,   "v*LLi*CLLi*iC", "")
BUILTIN(__builtin_brev_ldw,   "v*i*Ci*iC", "")
BUILTIN(__builtin_brev_ldh,   "v*s*Cs*iC", "")
BUILTIN(__builtin_brev_lduh,  "v*Us*CUs*iC", "")
BUILTIN(__builtin_brev_ldb,   "v*Sc*CSc*iC", "")
BUILTIN(__builtin_brev_ldub,  "v*Uc*CUc*iC", "")
BUILTIN(__builtin_circ_ldd,   "LLi*LLi*LLi*iIi", "")
BUILTIN(__builtin_circ_ldw,   "i*i*i*iIi", "")
BUILTIN(__builtin_circ_ldh,   "s*s*s*iIi", "")
BUILTIN(__builtin_circ_lduh,  "Us*Us*Us*iIi", "")
BUILTIN(__builtin_circ_ldb,   "c*c*c*iIi", "")
BUILTIN(__builtin_circ_ldub,  "Uc*Uc*Uc*iIi", "")
BUILTIN(__builtin_brev_std,   "LLi*CLLi*LLiiC", "")
BUILTIN(__builtin_brev_stw,   "i*Ci*iiC", "")
BUILTIN(__builtin_brev_sth,   "s*Cs*iiC", "")
BUILTIN(__builtin_brev_sthhi, "s*Cs*iiC", "")
BUILTIN(__builtin_brev_stb,   "c*Cc*iiC", "")
BUILTIN(__builtin_circ_std,   "LLi*LLi*LLiiIi", "")
BUILTIN(__builtin_circ_stw,   "i*i*iiIi", "")
BUILTIN(__builtin_circ_sth,   "s*s*iiIi", "")
BUILTIN(__builtin_circ_sthhi, "s*s*iiIi", "")
BUILTIN(__builtin_circ_stb,   "c*c*iiIi", "")
BUILTIN(__builtin_HEXAGON_L2_loadrub_pci, "iv*IiivC*", "")
BUILTIN(__builtin_HEXAGON_L2_loadrb_pci, "iv*IiivC*", "")
BUILTIN(__builtin_HEXAGON_L2_loadruh_pci, "iv*IiivC*", "")
BUILTIN(__builtin_HEXAGON_L2_loadrh_pci, "iv*IiivC*", "")
BUILTIN(__builtin_HEXAGON_L2_loadri_pci, "iv*IiivC*", "")
BUILTIN(__builtin_HEXAGON_L2_loadrd_pci, "LLiv*IiivC*", "")
BUILTIN(__builtin_HEXAGON_L2_loadrub_pcr, "iv*ivC*", "")
BUILTIN(__builtin_HEXAGON_L2_loadrb_pcr, "iv*ivC*", "")
BUILTIN(__builtin_HEXAGON_L2_loadruh_pcr, "iv*ivC*", "")
BUILTIN(__builtin_HEXAGON_L2_loadrh_pcr, "iv*ivC*", "")
BUILTIN(__builtin_HEXAGON_L2_loadri_pcr, "iv*ivC*", "")
BUILTIN(__builtin_HEXAGON_L2_loadrd_pcr, "LLiv*ivC*", "")

BUILTIN(__builtin_HEXAGON_S2_storerb_pci, "vv*IiiivC*", "")
BUILTIN(__builtin_HEXAGON_S2_storerh_pci, "vv*IiiivC*", "")
BUILTIN(__builtin_HEXAGON_S2_storerf_pci, "vv*IiiivC*", "")
BUILTIN(__builtin_HEXAGON_S2_storeri_pci, "vv*IiiivC*", "")
BUILTIN(__builtin_HEXAGON_S2_storerd_pci, "vv*IiiLLivC*", "")
BUILTIN(__builtin_HEXAGON_S2_storerb_pcr, "vv*iivC*", "")
BUILTIN(__builtin_HEXAGON_S2_storerh_pcr, "vv*iivC*", "")
BUILTIN(__builtin_HEXAGON_S2_storerf_pcr, "vv*iivC*", "")
BUILTIN(__builtin_HEXAGON_S2_storeri_pcr, "vv*iivC*", "")
BUILTIN(__builtin_HEXAGON_S2_storerd_pcr, "vv*iLLivC*", "")

BUILTIN(__builtin_HEXAGON_prefetch,"vv*","")
BUILTIN(__builtin_HEXAGON_Y2_dccleana,"vv*","")
BUILTIN(__builtin_HEXAGON_Y2_dccleaninva,"vv*","")
BUILTIN(__builtin_HEXAGON_Y2_dcinva,"vv*","")
BUILTIN(__builtin_HEXAGON_Y2_dczeroa,"vv*","")
BUILTIN(__builtin_HEXAGON_Y4_l2fetch,"vv*Ui","")
BUILTIN(__builtin_HEXAGON_Y5_l2fetch,"vv*LLUi","")

BUILTIN(__builtin_HEXAGON_V6_vS32b_qpred_ai,"vV16iv*V16i","")
BUILTIN(__builtin_HEXAGON_V6_vS32b_nqpred_ai,"vV16iv*V16i","")
BUILTIN(__builtin_HEXAGON_V6_vS32b_nt_qpred_ai,"vV16iv*V16i","")
BUILTIN(__builtin_HEXAGON_V6_vS32b_nt_nqpred_ai,"vV16iv*V16i","")
BUILTIN(__builtin_HEXAGON_V6_vS32b_qpred_ai_128B,"vV32iv*V32i","")
BUILTIN(__builtin_HEXAGON_V6_vS32b_nqpred_ai_128B,"vV32iv*V32i","")
BUILTIN(__builtin_HEXAGON_V6_vS32b_nt_qpred_ai_128B,"vV32iv*V32i","")
BUILTIN(__builtin_HEXAGON_V6_vS32b_nt_nqpred_ai_128B,"vV32iv*V32i","")
BUILTIN(__builtin_HEXAGON_V6_vmaskedstoreq,"vV16iv*V16i","")
BUILTIN(__builtin_HEXAGON_V6_vmaskedstorenq,"vV16iv*V16i","")
BUILTIN(__builtin_HEXAGON_V6_vmaskedstorentq,"vV16iv*V16i","")
BUILTIN(__builtin_HEXAGON_V6_vmaskedstorentnq,"vV16iv*V16i","")
BUILTIN(__builtin_HEXAGON_V6_vmaskedstoreq_128B,"vV32iv*V32i","")
BUILTIN(__builtin_HEXAGON_V6_vmaskedstorenq_128B,"vV32iv*V32i","")
BUILTIN(__builtin_HEXAGON_V6_vmaskedstorentq_128B,"vV32iv*V32i","")
BUILTIN(__builtin_HEXAGON_V6_vmaskedstorentnq_128B,"vV32iv*V32i","")

BUILTIN(__builtin_HEXAGON_V6_vgathermw,"vv*iiV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgathermw_128B,"vv*iiV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgathermh,"vv*iiV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgathermh_128B,"vv*iiV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgathermhw,"vv*iiV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgathermhw_128B,"vv*iiV64i","")
BUILTIN(__builtin_HEXAGON_V6_vgathermwq,"vv*V16iiiV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgathermwq_128B,"vv*V32iiiV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgathermhq,"vv*V16iiiV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgathermhq_128B,"vv*V32iiiV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgathermhwq,"vv*V16iiiV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgathermhwq_128B,"vv*V32iiiV64i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermw,"viiV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermw_128B,"viiV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermh,"viiV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermh_128B,"viiV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermw_add,"viiV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermw_add_128B,"viiV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermh_add,"viiV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermh_add_128B,"viiV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermwq,"vV16iiiV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermwq_128B,"vV32iiiV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermhq,"vV16iiiV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermhq_128B,"vV32iiiV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermhw,"viiV32iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermhw_128B,"viiV64iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermhwq,"vV16iiiV32iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermhwq_128B,"vV32iiiV64iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermhw_add,"viiV32iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vscattermhw_add_128B,"viiV64iV32i","")

// ---------------------------------------------------------------------
// Auto-generated definitions.

// V5 Scalar Instructions.

BUILTIN(__builtin_HEXAGON_S2_asr_r_p_or,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_S2_vsatwh,"iLLi","")
BUILTIN(__builtin_HEXAGON_S2_tableidxd_goodsyntax,"iiiUIiUIi","")
BUILTIN(__builtin_HEXAGON_M2_mpysu_up,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_acc_ll_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_acc_ll_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_cmpysc_s1,"LLiii","")
BUILTIN(__builtin_HEXAGON_M2_cmpysc_s0,"LLiii","")
BUILTIN(__builtin_HEXAGON_M4_cmpyi_whc,"iLLii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_sat_rnd_lh_s1,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_sat_rnd_lh_s0,"iii","")
BUILTIN(__builtin_HEXAGON_S2_tableidxb_goodsyntax,"iiiUIiUIi","")
BUILTIN(__builtin_HEXAGON_S2_shuffoh,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_F2_sfmax,"fff","")
BUILTIN(__builtin_HEXAGON_A2_vabswsat,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_r,"iiUIi","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_p,"LLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_A4_combineri,"LLiiIi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_nac_sat_hl_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_M4_vpmpyh_acc,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_vcmpy_s0_sat_i,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_notp,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_hl_s1,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_hl_s0,"iii","")
BUILTIN(__builtin_HEXAGON_C4_or_and,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_vmac2s_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_vmac2s_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_S2_brevp,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_M4_pmpyw_acc,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_S2_cl1,"ii","")
BUILTIN(__builtin_HEXAGON_C4_cmplte,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mmpyul_s0,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vaddws,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_maxup,"ULLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A4_vcmphgti,"iLLiIi","")
BUILTIN(__builtin_HEXAGON_S2_interleave,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vrcmpyi_s0,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_abssat,"ii","")
BUILTIN(__builtin_HEXAGON_A2_vcmpwgtu,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_C2_cmpgtu,"iii","")
BUILTIN(__builtin_HEXAGON_C2_cmpgtp,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_A4_cmphgtui,"iiUIi","")
BUILTIN(__builtin_HEXAGON_C2_cmpgti,"iiIi","")
BUILTIN(__builtin_HEXAGON_M2_mpyi,"iii","")
BUILTIN(__builtin_HEXAGON_F2_conv_df2uw_chop,"id","")
BUILTIN(__builtin_HEXAGON_A4_cmpheq,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_lh_s1,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_lh_s0,"iii","")
BUILTIN(__builtin_HEXAGON_S2_lsr_i_r_xacc,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_S2_vrcnegh,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_S2_extractup,"LLiLLiUIiUIi","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_p_rnd_goodsyntax,"LLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_S4_ntstbit_r,"iii","")
BUILTIN(__builtin_HEXAGON_F2_conv_w2sf,"fi","")
BUILTIN(__builtin_HEXAGON_C2_not,"ii","")
BUILTIN(__builtin_HEXAGON_C2_tfrpr,"ii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_ll_s1,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_ll_s0,"iii","")
BUILTIN(__builtin_HEXAGON_A4_cmpbgt,"iii","")
BUILTIN(__builtin_HEXAGON_S2_asr_r_r_and,"iiii","")
BUILTIN(__builtin_HEXAGON_A4_rcmpneqi,"iiIi","")
BUILTIN(__builtin_HEXAGON_S2_asl_i_r_nac,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_M2_subacc,"iiii","")
BUILTIN(__builtin_HEXAGON_A2_orp,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_up,"Uiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_acc_sat_lh_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_vh,"LLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_vw,"LLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_A4_cmpbgtu,"iii","")
BUILTIN(__builtin_HEXAGON_A4_vcmpbeq_any,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_A4_cmpbgti,"iiIi","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_lh_s1,"LLiii","")
BUILTIN(__builtin_HEXAGON_S2_asl_r_p_nac,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_S2_lsr_i_r_nac,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_A2_addsp,"LLiiLLi","")
BUILTIN(__builtin_HEXAGON_S4_vxsubaddw,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A4_vcmpheqi,"iLLiIi","")
BUILTIN(__builtin_HEXAGON_S4_vxsubaddh,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M4_pmpyw,"LLiii","")
BUILTIN(__builtin_HEXAGON_S2_vsathb,"iLLi","")
BUILTIN(__builtin_HEXAGON_S2_asr_r_p_and,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_acc_lh_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_acc_lh_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_S2_lsl_r_p_acc,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_A2_pxorf,"iiii","")
BUILTIN(__builtin_HEXAGON_C2_cmpgei,"iiIi","")
BUILTIN(__builtin_HEXAGON_A2_vsubub,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_asl_i_p,"LLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_S2_asl_i_r,"iiUIi","")
BUILTIN(__builtin_HEXAGON_A4_vrminuw,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_F2_sffma,"ffff","")
BUILTIN(__builtin_HEXAGON_A2_absp,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_C2_all8,"ii","")
BUILTIN(__builtin_HEXAGON_A4_vrminuh,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_F2_sffma_lib,"ffff","")
BUILTIN(__builtin_HEXAGON_M4_vrmpyoh_s0,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M4_vrmpyoh_s1,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_C2_bitsset,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpysip,"iiUIi","")
BUILTIN(__builtin_HEXAGON_M2_mpysin,"iiUIi","")
BUILTIN(__builtin_HEXAGON_A4_boundscheck,"iiLLi","")
BUILTIN(__builtin_HEXAGON_M5_vrmpybuu,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_C4_fastcorner9,"iii","")
BUILTIN(__builtin_HEXAGON_M2_vrcmpys_s1rp,"iLLii","")
BUILTIN(__builtin_HEXAGON_A2_neg,"ii","")
BUILTIN(__builtin_HEXAGON_A2_subsat,"iii","")
BUILTIN(__builtin_HEXAGON_S2_asl_r_r,"iii","")
BUILTIN(__builtin_HEXAGON_S2_asl_r_p,"LLiLLii","")
BUILTIN(__builtin_HEXAGON_A2_vnavgh,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_nac_sat_hl_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_F2_conv_ud2df,"dLLi","")
BUILTIN(__builtin_HEXAGON_A2_vnavgw,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_asl_i_r_acc,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_S4_subi_lsr_ri,"iUIiiUIi","")
BUILTIN(__builtin_HEXAGON_S2_vzxthw,"LLii","")
BUILTIN(__builtin_HEXAGON_F2_sfadd,"fff","")
BUILTIN(__builtin_HEXAGON_A2_sub,"iii","")
BUILTIN(__builtin_HEXAGON_M2_vmac2su_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_vmac2su_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_dpmpyss_s0,"LLiii","")
BUILTIN(__builtin_HEXAGON_S2_insert,"iiiUIiUIi","")
BUILTIN(__builtin_HEXAGON_S2_packhl,"LLiii","")
BUILTIN(__builtin_HEXAGON_A4_vcmpwgti,"iLLiIi","")
BUILTIN(__builtin_HEXAGON_A2_vavguwr,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_asl_r_r_and,"iiii","")
BUILTIN(__builtin_HEXAGON_A2_svsubhs,"iii","")
BUILTIN(__builtin_HEXAGON_A2_addh_l16_hl,"iii","")
BUILTIN(__builtin_HEXAGON_M4_and_and,"iiii","")
BUILTIN(__builtin_HEXAGON_F2_conv_d2df,"dLLi","")
BUILTIN(__builtin_HEXAGON_C2_cmpgtui,"iiUIi","")
BUILTIN(__builtin_HEXAGON_A2_vconj,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_lsr_r_vw,"LLiLLii","")
BUILTIN(__builtin_HEXAGON_S2_lsr_r_vh,"LLiLLii","")
BUILTIN(__builtin_HEXAGON_A2_subh_l16_hl,"iii","")
BUILTIN(__builtin_HEXAGON_S4_vxsubaddhr,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_clbp,"iLLi","")
BUILTIN(__builtin_HEXAGON_S2_deinterleave,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_C2_any8,"ii","")
BUILTIN(__builtin_HEXAGON_S2_togglebit_r,"iii","")
BUILTIN(__builtin_HEXAGON_S2_togglebit_i,"iiUIi","")
BUILTIN(__builtin_HEXAGON_F2_conv_uw2sf,"fi","")
BUILTIN(__builtin_HEXAGON_S2_vsathb_nopack,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_cmacs_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_cmacs_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_sat_hh_s0,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_sat_hh_s1,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mmacuhs_s1,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mmacuhs_s0,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_clrbit_r,"iii","")
BUILTIN(__builtin_HEXAGON_C4_or_andn,"iiii","")
BUILTIN(__builtin_HEXAGON_S2_asl_r_r_nac,"iiii","")
BUILTIN(__builtin_HEXAGON_S2_asl_i_p_acc,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_A4_vcmpwgtui,"iLLiUIi","")
BUILTIN(__builtin_HEXAGON_M4_vrmpyoh_acc_s0,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M4_vrmpyoh_acc_s1,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A4_vrmaxh,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_A2_vcmpbeq,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vcmphgt,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vnavgwcr,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vrcmacr_s0c,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vavgwcr,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_asl_i_p_xacc,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_A4_vrmaxw,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_A2_vnavghr,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M4_cmpyi_wh,"iLLii","")
BUILTIN(__builtin_HEXAGON_A2_tfrsi,"iIi","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_r_acc,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_A2_svnavgh,"iii","")
BUILTIN(__builtin_HEXAGON_S2_lsr_i_r,"iiUIi","")
BUILTIN(__builtin_HEXAGON_M2_vmac2,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_A4_vcmphgtui,"iLLiUIi","")
BUILTIN(__builtin_HEXAGON_A2_svavgh,"iii","")
BUILTIN(__builtin_HEXAGON_M4_vrmpyeh_acc_s0,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M4_vrmpyeh_acc_s1,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_lsr_i_p,"LLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_A2_combine_hl,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_up,"iii","")
BUILTIN(__builtin_HEXAGON_A2_combine_hh,"iii","")
BUILTIN(__builtin_HEXAGON_A2_negsat,"ii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_hl_s0,"LLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_hl_s1,"LLiii","")
BUILTIN(__builtin_HEXAGON_A4_bitsplit,"LLiii","")
BUILTIN(__builtin_HEXAGON_A2_vabshsat,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpyui,"iii","")
BUILTIN(__builtin_HEXAGON_A2_addh_l16_sat_ll,"iii","")
BUILTIN(__builtin_HEXAGON_S2_lsl_r_r_and,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mmpyul_rs0,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_r_rnd_goodsyntax,"iiUIi","")
BUILTIN(__builtin_HEXAGON_S2_lsr_r_p_nac,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_C2_cmplt,"iii","")
BUILTIN(__builtin_HEXAGON_M2_cmacr_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M4_or_and,"iiii","")
BUILTIN(__builtin_HEXAGON_M4_mpyrr_addi,"iUIiii","")
BUILTIN(__builtin_HEXAGON_S4_or_andi,"iiiIi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_sat_hl_s0,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_sat_hl_s1,"iii","")
BUILTIN(__builtin_HEXAGON_M4_mpyrr_addr,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mmachs_rs0,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mmachs_rs1,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vrcmpyr_s0c,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_acc_sat_hl_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_acc_ll_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_F2_sffixupn,"fff","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_acc_lh_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_acc_lh_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_rnd_hh_s0,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_rnd_hh_s1,"iii","")
BUILTIN(__builtin_HEXAGON_A2_vadduhs,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vsubuhs,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_subh_h16_hl,"iii","")
BUILTIN(__builtin_HEXAGON_A2_subh_h16_hh,"iii","")
BUILTIN(__builtin_HEXAGON_A2_xorp,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A4_tfrpcp,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_addh_h16_lh,"iii","")
BUILTIN(__builtin_HEXAGON_A2_addh_h16_sat_hl,"iii","")
BUILTIN(__builtin_HEXAGON_A2_addh_h16_ll,"iii","")
BUILTIN(__builtin_HEXAGON_A2_addh_h16_sat_hh,"iii","")
BUILTIN(__builtin_HEXAGON_A2_zxtb,"ii","")
BUILTIN(__builtin_HEXAGON_A2_zxth,"ii","")
BUILTIN(__builtin_HEXAGON_A2_vnavgwr,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M4_or_xor,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_acc_hh_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_acc_hh_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M5_vmacbsu,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_dpmpyuu_acc_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_rnd_hl_s0,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_rnd_hl_s1,"iii","")
BUILTIN(__builtin_HEXAGON_F2_sffms_lib,"ffff","")
BUILTIN(__builtin_HEXAGON_C4_cmpneqi,"iiIi","")
BUILTIN(__builtin_HEXAGON_M4_and_xor,"iiii","")
BUILTIN(__builtin_HEXAGON_A2_sat,"iLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_nac_lh_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_nac_lh_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_A2_addsat,"iii","")
BUILTIN(__builtin_HEXAGON_A2_svavghs,"iii","")
BUILTIN(__builtin_HEXAGON_A2_vrsadub_acc,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_C2_bitsclri,"iiUIi","")
BUILTIN(__builtin_HEXAGON_A2_subh_h16_sat_hh,"iii","")
BUILTIN(__builtin_HEXAGON_A2_subh_h16_sat_hl,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mmaculs_rs0,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mmaculs_rs1,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vradduh,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_A4_addp_c,"LLiLLiLLiv*","")
BUILTIN(__builtin_HEXAGON_C2_xor,"iii","")
BUILTIN(__builtin_HEXAGON_S2_lsl_r_r_acc,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mmpyh_rs1,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mmpyh_rs0,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_F2_conv_df2ud_chop,"LLid","")
BUILTIN(__builtin_HEXAGON_C4_or_or,"iiii","")
BUILTIN(__builtin_HEXAGON_S4_vxaddsubhr,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_vsathub,"iLLi","")
BUILTIN(__builtin_HEXAGON_F2_conv_df2sf,"fd","")
BUILTIN(__builtin_HEXAGON_M2_hmmpyh_rs1,"iii","")
BUILTIN(__builtin_HEXAGON_M2_hmmpyh_s1,"iii","")
BUILTIN(__builtin_HEXAGON_A2_vavgwr,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_tableidxh_goodsyntax,"iiiUIiUIi","")
BUILTIN(__builtin_HEXAGON_A2_sxth,"ii","")
BUILTIN(__builtin_HEXAGON_A2_sxtb,"ii","")
BUILTIN(__builtin_HEXAGON_C4_or_orn,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_vrcmaci_s0c,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_sxtw,"LLii","")
BUILTIN(__builtin_HEXAGON_M2_vabsdiffh,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_acc_lh_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_acc_lh_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_hmmpyl_s1,"iii","")
BUILTIN(__builtin_HEXAGON_S2_cl1p,"iLLi","")
BUILTIN(__builtin_HEXAGON_M2_vabsdiffw,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A4_andnp,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_C2_vmux,"LLiiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_parityp,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_lsr_i_p_and,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_r_or,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_nac_ll_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_nac_ll_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_F2_sfcmpeq,"iff","")
BUILTIN(__builtin_HEXAGON_A2_vaddb_map,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_lsr_r_r_nac,"iiii","")
BUILTIN(__builtin_HEXAGON_A2_vcmpheq,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_clbnorm,"ii","")
BUILTIN(__builtin_HEXAGON_M2_cnacsc_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_cnacsc_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_S4_subaddi,"iiIii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_nac_hl_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_nac_hl_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_S5_vasrhrnd_goodsyntax,"LLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_S2_tstbit_r,"iii","")
BUILTIN(__builtin_HEXAGON_S4_vrcrotate,"LLiLLiiUIi","")
BUILTIN(__builtin_HEXAGON_M2_mmachs_s1,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mmachs_s0,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_tstbit_i,"iiUIi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_up_s1,"iii","")
BUILTIN(__builtin_HEXAGON_S2_extractu_rp,"iiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mmpyuh_rs0,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_lsr_i_vw,"LLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_rnd_ll_s0,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_rnd_ll_s1,"iii","")
BUILTIN(__builtin_HEXAGON_M4_or_or,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_hh_s1,"Uiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_hh_s0,"Uiii","")
BUILTIN(__builtin_HEXAGON_S2_asl_r_p_acc,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_nac_lh_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_nac_lh_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_sat_ll_s0,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_sat_ll_s1,"iii","")
BUILTIN(__builtin_HEXAGON_F2_conv_w2df,"di","")
BUILTIN(__builtin_HEXAGON_A2_subh_l16_sat_hl,"iii","")
BUILTIN(__builtin_HEXAGON_C2_cmpeqi,"iiIi","")
BUILTIN(__builtin_HEXAGON_S2_asl_i_r_and,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_S2_vcnegh,"LLiLLii","")
BUILTIN(__builtin_HEXAGON_A4_vcmpweqi,"iLLiIi","")
BUILTIN(__builtin_HEXAGON_M2_vdmpyrs_s0,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vdmpyrs_s1,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_M4_xor_xacc,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vdmpys_s1,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vdmpys_s0,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vavgubr,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_hl_s1,"Uiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_hl_s0,"Uiii","")
BUILTIN(__builtin_HEXAGON_S2_asl_r_r_acc,"iiii","")
BUILTIN(__builtin_HEXAGON_S2_cl0p,"iLLi","")
BUILTIN(__builtin_HEXAGON_S2_valignib,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_F2_sffixupd,"fff","")
BUILTIN(__builtin_HEXAGON_M2_mpy_sat_rnd_hl_s1,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_sat_rnd_hl_s0,"iii","")
BUILTIN(__builtin_HEXAGON_M2_cmacsc_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_cmacsc_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_S2_ct1,"ii","")
BUILTIN(__builtin_HEXAGON_S2_ct0,"ii","")
BUILTIN(__builtin_HEXAGON_M2_dpmpyuu_nac_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mmpyul_rs1,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S4_ntstbit_i,"iiUIi","")
BUILTIN(__builtin_HEXAGON_F2_sffixupr,"ff","")
BUILTIN(__builtin_HEXAGON_S2_asr_r_p_xor,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_acc_hl_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_acc_hl_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_A2_vcmphgtu,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_C2_andn,"iii","")
BUILTIN(__builtin_HEXAGON_M2_vmpy2s_s0pack,"iii","")
BUILTIN(__builtin_HEXAGON_S4_addaddi,"iiiIi","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_acc_ll_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_acc_sat_hl_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_A4_rcmpeqi,"iiIi","")
BUILTIN(__builtin_HEXAGON_M4_xor_and,"iiii","")
BUILTIN(__builtin_HEXAGON_S2_asl_i_p_and,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_M2_mmpyuh_rs1,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_asr_r_r_or,"iiii","")
BUILTIN(__builtin_HEXAGON_A4_round_ri,"iiUIi","")
BUILTIN(__builtin_HEXAGON_A2_max,"iii","")
BUILTIN(__builtin_HEXAGON_A4_round_rr,"iii","")
BUILTIN(__builtin_HEXAGON_A4_combineii,"LLiIiUIi","")
BUILTIN(__builtin_HEXAGON_A4_combineir,"LLiIii","")
BUILTIN(__builtin_HEXAGON_C4_and_orn,"iiii","")
BUILTIN(__builtin_HEXAGON_M5_vmacbuu,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_A4_rcmpeq,"iii","")
BUILTIN(__builtin_HEXAGON_M4_cmpyr_whc,"iLLii","")
BUILTIN(__builtin_HEXAGON_S2_lsr_i_r_acc,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_S2_vzxtbh,"LLii","")
BUILTIN(__builtin_HEXAGON_M2_mmacuhs_rs1,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_asr_r_r_sat,"iii","")
BUILTIN(__builtin_HEXAGON_A2_combinew,"LLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_acc_ll_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_acc_ll_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_cmpyi_s0,"LLiii","")
BUILTIN(__builtin_HEXAGON_S2_asl_r_p_or,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_S4_ori_asl_ri,"iUIiiUIi","")
BUILTIN(__builtin_HEXAGON_C4_nbitsset,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_acc_hh_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_acc_hh_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_ll_s1,"Uiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_ll_s0,"Uiii","")
BUILTIN(__builtin_HEXAGON_A2_addh_l16_ll,"iii","")
BUILTIN(__builtin_HEXAGON_S2_lsr_r_r_and,"iiii","")
BUILTIN(__builtin_HEXAGON_A4_modwrapu,"iii","")
BUILTIN(__builtin_HEXAGON_A4_rcmpneq,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_acc_hh_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_acc_hh_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_F2_sfimm_p,"fUIi","")
BUILTIN(__builtin_HEXAGON_F2_sfimm_n,"fUIi","")
BUILTIN(__builtin_HEXAGON_M4_cmpyr_wh,"iLLii","")
BUILTIN(__builtin_HEXAGON_S2_lsl_r_p_and,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_A2_vavgub,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_F2_conv_d2sf,"fLLi","")
BUILTIN(__builtin_HEXAGON_A2_vavguh,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A4_cmpbeqi,"iiUIi","")
BUILTIN(__builtin_HEXAGON_F2_sfcmpuo,"iff","")
BUILTIN(__builtin_HEXAGON_A2_vavguw,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_p_nac,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_S2_vsatwh_nopack,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_hh_s0,"LLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_hh_s1,"LLiii","")
BUILTIN(__builtin_HEXAGON_S2_lsl_r_p_or,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_A2_minu,"Uiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_sat_lh_s1,"iii","")
BUILTIN(__builtin_HEXAGON_M4_or_andn,"iiii","")
BUILTIN(__builtin_HEXAGON_A2_minp,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S4_or_andix,"iiiIi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_rnd_lh_s0,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_rnd_lh_s1,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mmpyuh_s0,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mmpyuh_s1,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_acc_sat_lh_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_F2_sfcmpge,"iff","")
BUILTIN(__builtin_HEXAGON_F2_sfmin,"fff","")
BUILTIN(__builtin_HEXAGON_F2_sfcmpgt,"iff","")
BUILTIN(__builtin_HEXAGON_M4_vpmpyh,"LLiii","")
BUILTIN(__builtin_HEXAGON_M2_mmacuhs_rs0,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_rnd_lh_s1,"LLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_rnd_lh_s0,"LLiii","")
BUILTIN(__builtin_HEXAGON_A2_roundsat,"iLLi","")
BUILTIN(__builtin_HEXAGON_S2_ct1p,"iLLi","")
BUILTIN(__builtin_HEXAGON_S4_extract_rp,"iiLLi","")
BUILTIN(__builtin_HEXAGON_S2_lsl_r_r_or,"iiii","")
BUILTIN(__builtin_HEXAGON_C4_cmplteui,"iiUIi","")
BUILTIN(__builtin_HEXAGON_S4_addi_lsr_ri,"iUIiiUIi","")
BUILTIN(__builtin_HEXAGON_A4_tfrcpp,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_svw_trun,"iLLiUIi","")
BUILTIN(__builtin_HEXAGON_A4_cmphgti,"iiIi","")
BUILTIN(__builtin_HEXAGON_A4_vrminh,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_A4_vrminw,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_A4_cmphgtu,"iii","")
BUILTIN(__builtin_HEXAGON_S2_insertp_rp,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vnavghcr,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S4_subi_asl_ri,"iUIiiUIi","")
BUILTIN(__builtin_HEXAGON_S2_lsl_r_vh,"LLiLLii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_hh_s0,"iii","")
BUILTIN(__builtin_HEXAGON_A2_vsubws,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_sath,"ii","")
BUILTIN(__builtin_HEXAGON_S2_asl_r_p_xor,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_A2_satb,"ii","")
BUILTIN(__builtin_HEXAGON_C2_cmpltu,"iii","")
BUILTIN(__builtin_HEXAGON_S2_insertp,"LLiLLiLLiUIiUIi","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_rnd_ll_s1,"LLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_rnd_ll_s0,"LLiii","")
BUILTIN(__builtin_HEXAGON_S2_lsr_i_p_nac,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_S2_extractup_rp,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S4_vxaddsubw,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S4_vxaddsubh,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_asrh,"ii","")
BUILTIN(__builtin_HEXAGON_S4_extractp_rp,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_lsr_r_r_acc,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_nac_ll_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_nac_ll_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_C2_or,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mmpyul_s1,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vrcmacr_s0,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_xor,"iii","")
BUILTIN(__builtin_HEXAGON_A2_add,"iii","")
BUILTIN(__builtin_HEXAGON_A2_vsububs,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vmpy2s_s1,"LLiii","")
BUILTIN(__builtin_HEXAGON_M2_vmpy2s_s0,"LLiii","")
BUILTIN(__builtin_HEXAGON_A2_vraddub_acc,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_F2_sfinvsqrta,"ff","")
BUILTIN(__builtin_HEXAGON_S2_ct0p,"iLLi","")
BUILTIN(__builtin_HEXAGON_A2_svaddh,"iii","")
BUILTIN(__builtin_HEXAGON_S2_vcrotate,"LLiLLii","")
BUILTIN(__builtin_HEXAGON_A2_aslh,"ii","")
BUILTIN(__builtin_HEXAGON_A2_subh_h16_lh,"iii","")
BUILTIN(__builtin_HEXAGON_A2_subh_h16_ll,"iii","")
BUILTIN(__builtin_HEXAGON_M2_hmmpyl_rs1,"iii","")
BUILTIN(__builtin_HEXAGON_S2_asr_r_p,"LLiLLii","")
BUILTIN(__builtin_HEXAGON_S2_vsplatrh,"LLii","")
BUILTIN(__builtin_HEXAGON_S2_asr_r_r,"iii","")
BUILTIN(__builtin_HEXAGON_A2_addh_h16_hl,"iii","")
BUILTIN(__builtin_HEXAGON_S2_vsplatrb,"ii","")
BUILTIN(__builtin_HEXAGON_A2_addh_h16_hh,"iii","")
BUILTIN(__builtin_HEXAGON_M2_cmpyr_s0,"LLiii","")
BUILTIN(__builtin_HEXAGON_M2_dpmpyss_rnd_s0,"iii","")
BUILTIN(__builtin_HEXAGON_C2_muxri,"iiIii","")
BUILTIN(__builtin_HEXAGON_M2_vmac2es_s0,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vmac2es_s1,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_C2_pxfer_map,"ii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_lh_s1,"Uiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_lh_s0,"Uiii","")
BUILTIN(__builtin_HEXAGON_S2_asl_i_r_or,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_acc_hl_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_acc_hl_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_S2_asr_r_p_nac,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_A2_vaddw,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_r_and,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_A2_vaddh,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_nac_sat_lh_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_nac_sat_lh_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_C2_cmpeqp,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_M4_mpyri_addi,"iUIiiUIi","")
BUILTIN(__builtin_HEXAGON_A2_not,"ii","")
BUILTIN(__builtin_HEXAGON_S4_andi_lsr_ri,"iUIiiUIi","")
BUILTIN(__builtin_HEXAGON_M2_macsip,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_A2_tfrcrr,"ii","")
BUILTIN(__builtin_HEXAGON_M2_macsin,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_C2_orn,"iii","")
BUILTIN(__builtin_HEXAGON_M4_and_andn,"iiii","")
BUILTIN(__builtin_HEXAGON_F2_sfmpy,"fff","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_nac_hh_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_nac_hh_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_S2_lsr_r_p_acc,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_S2_asr_r_vw,"LLiLLii","")
BUILTIN(__builtin_HEXAGON_M4_and_or,"iiii","")
BUILTIN(__builtin_HEXAGON_S2_asr_r_vh,"LLiLLii","")
BUILTIN(__builtin_HEXAGON_C2_mask,"LLii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_nac_hh_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_nac_hh_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_up_s1_sat,"iii","")
BUILTIN(__builtin_HEXAGON_A4_vcmpbgt,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_M5_vrmacbsu,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_tableidxw_goodsyntax,"iiiUIiUIi","")
BUILTIN(__builtin_HEXAGON_A2_vrsadub,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_tfrrcr,"ii","")
BUILTIN(__builtin_HEXAGON_M2_vrcmpys_acc_s1,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_F2_dfcmpge,"idd","")
BUILTIN(__builtin_HEXAGON_M2_accii,"iiiIi","")
BUILTIN(__builtin_HEXAGON_A5_vaddhubs,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vmaxw,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vmaxb,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vmaxh,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_vsxthw,"LLii","")
BUILTIN(__builtin_HEXAGON_S4_andi_asl_ri,"iUIiiUIi","")
BUILTIN(__builtin_HEXAGON_S2_asl_i_p_nac,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_S2_lsl_r_p_xor,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_C2_cmpgt,"iii","")
BUILTIN(__builtin_HEXAGON_F2_conv_df2d_chop,"LLid","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_nac_hl_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_nac_hl_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_F2_conv_sf2w,"if","")
BUILTIN(__builtin_HEXAGON_S2_lsr_r_p_or,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_F2_sfclass,"ifUIi","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_acc_lh_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M4_xor_andn,"iiii","")
BUILTIN(__builtin_HEXAGON_S2_addasl_rrri,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_M5_vdmpybsu,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_nac_hh_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_nac_hh_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_A2_addi,"iiIi","")
BUILTIN(__builtin_HEXAGON_A2_addp,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vmpy2s_s1pack,"iii","")
BUILTIN(__builtin_HEXAGON_S4_clbpnorm,"iLLi","")
BUILTIN(__builtin_HEXAGON_A4_round_rr_sat,"iii","")
BUILTIN(__builtin_HEXAGON_M2_nacci,"iiii","")
BUILTIN(__builtin_HEXAGON_S2_shuffeh,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_lsr_i_r_and,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_sat_rnd_hh_s1,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_sat_rnd_hh_s0,"iii","")
BUILTIN(__builtin_HEXAGON_F2_conv_sf2uw,"if","")
BUILTIN(__builtin_HEXAGON_A2_vsubh,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_F2_conv_sf2ud,"LLif","")
BUILTIN(__builtin_HEXAGON_A2_vsubw,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vcmpwgt,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_M4_xor_or,"iiii","")
BUILTIN(__builtin_HEXAGON_F2_conv_sf2uw_chop,"if","")
BUILTIN(__builtin_HEXAGON_S2_asl_r_vw,"LLiLLii","")
BUILTIN(__builtin_HEXAGON_S2_vsatwuh_nopack,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_asl_r_vh,"LLiLLii","")
BUILTIN(__builtin_HEXAGON_A2_svsubuhs,"iii","")
BUILTIN(__builtin_HEXAGON_M5_vmpybsu,"LLiii","")
BUILTIN(__builtin_HEXAGON_A2_subh_l16_sat_ll,"iii","")
BUILTIN(__builtin_HEXAGON_C4_and_and,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_acc_hl_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_acc_hl_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_S2_lsr_r_p,"LLiLLii","")
BUILTIN(__builtin_HEXAGON_S2_lsr_r_r,"iii","")
BUILTIN(__builtin_HEXAGON_A4_subp_c,"LLiLLiLLiv*","")
BUILTIN(__builtin_HEXAGON_A2_vsubhs,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_C2_vitpack,"iii","")
BUILTIN(__builtin_HEXAGON_A2_vavguhr,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_vsplicerb,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_C4_nbitsclr,"iii","")
BUILTIN(__builtin_HEXAGON_A2_vcmpbgtu,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_cmpys_s1,"LLiii","")
BUILTIN(__builtin_HEXAGON_M2_cmpys_s0,"LLiii","")
BUILTIN(__builtin_HEXAGON_F2_dfcmpuo,"idd","")
BUILTIN(__builtin_HEXAGON_S2_shuffob,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_C2_and,"iii","")
BUILTIN(__builtin_HEXAGON_S5_popcountp,"iLLi","")
BUILTIN(__builtin_HEXAGON_S4_extractp,"LLiLLiUIiUIi","")
BUILTIN(__builtin_HEXAGON_S2_cl0,"ii","")
BUILTIN(__builtin_HEXAGON_A4_vcmpbgti,"iLLiIi","")
BUILTIN(__builtin_HEXAGON_M2_mmacls_s1,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mmacls_s0,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_C4_cmpneq,"iii","")
BUILTIN(__builtin_HEXAGON_M2_vmac2es,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vdmacs_s0,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vdmacs_s1,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_ll_s0,"ULLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_ll_s1,"ULLiii","")
BUILTIN(__builtin_HEXAGON_S2_clb,"ii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_nac_ll_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_nac_ll_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_nac_hl_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_nac_hl_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_maci,"iiii","")
BUILTIN(__builtin_HEXAGON_A2_vmaxuh,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A4_bitspliti,"LLiiUIi","")
BUILTIN(__builtin_HEXAGON_A2_vmaxub,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_hh_s0,"ULLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_hh_s1,"ULLiii","")
BUILTIN(__builtin_HEXAGON_M2_vrmac_s0,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_sat_lh_s0,"iii","")
BUILTIN(__builtin_HEXAGON_S2_asl_r_r_sat,"iii","")
BUILTIN(__builtin_HEXAGON_F2_conv_sf2d,"LLif","")
BUILTIN(__builtin_HEXAGON_S2_asr_r_r_nac,"iiii","")
BUILTIN(__builtin_HEXAGON_F2_dfimm_n,"dUIi","")
BUILTIN(__builtin_HEXAGON_A4_cmphgt,"iii","")
BUILTIN(__builtin_HEXAGON_F2_dfimm_p,"dUIi","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_acc_lh_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_vcmpy_s1_sat_r,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M4_mpyri_addr_u2,"iiUIii","")
BUILTIN(__builtin_HEXAGON_M2_vcmpy_s1_sat_i,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_lsl_r_p_nac,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_M5_vrmacbuu,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S5_asrhub_rnd_sat_goodsyntax,"iLLiUIi","")
BUILTIN(__builtin_HEXAGON_S2_vspliceib,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_M2_dpmpyss_acc_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_cnacs_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_cnacs_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_A2_maxu,"Uiii","")
BUILTIN(__builtin_HEXAGON_A2_maxp,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_andir,"iiIi","")
BUILTIN(__builtin_HEXAGON_F2_sfrecipa,"fff","")
BUILTIN(__builtin_HEXAGON_A2_combineii,"LLiIiIi","")
BUILTIN(__builtin_HEXAGON_A4_orn,"iii","")
BUILTIN(__builtin_HEXAGON_A4_cmpbgtui,"iiUIi","")
BUILTIN(__builtin_HEXAGON_S2_lsr_r_r_or,"iiii","")
BUILTIN(__builtin_HEXAGON_A4_vcmpbeqi,"iLLiUIi","")
BUILTIN(__builtin_HEXAGON_S2_lsl_r_r,"iii","")
BUILTIN(__builtin_HEXAGON_S2_lsl_r_p,"LLiLLii","")
BUILTIN(__builtin_HEXAGON_A2_or,"iii","")
BUILTIN(__builtin_HEXAGON_F2_dfcmpeq,"idd","")
BUILTIN(__builtin_HEXAGON_C2_cmpeq,"iii","")
BUILTIN(__builtin_HEXAGON_A2_tfrp,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_C4_and_andn,"iiii","")
BUILTIN(__builtin_HEXAGON_S2_vsathub_nopack,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_satuh,"ii","")
BUILTIN(__builtin_HEXAGON_A2_satub,"ii","")
BUILTIN(__builtin_HEXAGON_M2_vrcmpys_s1,"LLiLLii","")
BUILTIN(__builtin_HEXAGON_S4_or_ori,"iiiIi","")
BUILTIN(__builtin_HEXAGON_C4_fastcorner9_not,"iii","")
BUILTIN(__builtin_HEXAGON_A2_tfrih,"iiUIi","")
BUILTIN(__builtin_HEXAGON_A2_tfril,"iiUIi","")
BUILTIN(__builtin_HEXAGON_M4_mpyri_addr,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_S2_vtrunehb,"iLLi","")
BUILTIN(__builtin_HEXAGON_A2_vabsw,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vabsh,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_F2_sfsub,"fff","")
BUILTIN(__builtin_HEXAGON_C2_muxii,"iiIiIi","")
BUILTIN(__builtin_HEXAGON_C2_muxir,"iiiIi","")
BUILTIN(__builtin_HEXAGON_A2_swiz,"ii","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_p_and,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_M2_cmpyrsc_s0,"iii","")
BUILTIN(__builtin_HEXAGON_M2_cmpyrsc_s1,"iii","")
BUILTIN(__builtin_HEXAGON_A2_vraddub,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A4_tlbmatch,"iLLii","")
BUILTIN(__builtin_HEXAGON_F2_conv_df2w_chop,"id","")
BUILTIN(__builtin_HEXAGON_A2_and,"iii","")
BUILTIN(__builtin_HEXAGON_S2_lsr_r_p_and,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_nac_sat_ll_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_nac_sat_ll_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_S4_extract,"iiUIiUIi","")
BUILTIN(__builtin_HEXAGON_A2_vcmpweq,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_acci,"iiii","")
BUILTIN(__builtin_HEXAGON_S2_lsr_i_p_acc,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_S2_lsr_i_p_or,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_F2_conv_ud2sf,"fLLi","")
BUILTIN(__builtin_HEXAGON_A2_tfr,"ii","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_p_or,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_A2_subri,"iIii","")
BUILTIN(__builtin_HEXAGON_A4_vrmaxuw,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_M5_vmpybuu,"LLiii","")
BUILTIN(__builtin_HEXAGON_A4_vrmaxuh,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_S2_asl_i_vw,"LLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_A2_vavgw,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_brev,"ii","")
BUILTIN(__builtin_HEXAGON_A2_vavgh,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_clrbit_i,"iiUIi","")
BUILTIN(__builtin_HEXAGON_S2_asl_i_vh,"LLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_S2_lsr_i_r_or,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_S2_lsl_r_r_nac,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mmpyl_rs1,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_hl_s1,"ULLiii","")
BUILTIN(__builtin_HEXAGON_M2_mmpyl_s0,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mmpyl_s1,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_naccii,"iiiIi","")
BUILTIN(__builtin_HEXAGON_S2_vrndpackwhs,"iLLi","")
BUILTIN(__builtin_HEXAGON_S2_vtrunewh,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_dpmpyss_nac_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_ll_s0,"LLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_ll_s1,"LLiii","")
BUILTIN(__builtin_HEXAGON_M4_mac_up_s1_sat,"iiii","")
BUILTIN(__builtin_HEXAGON_S4_vrcrotate_acc,"LLiLLiLLiiUIi","")
BUILTIN(__builtin_HEXAGON_F2_conv_uw2df,"di","")
BUILTIN(__builtin_HEXAGON_A2_vaddubs,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_asr_r_r_acc,"iiii","")
BUILTIN(__builtin_HEXAGON_A2_orir,"iiIi","")
BUILTIN(__builtin_HEXAGON_A2_andp,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_lfsp,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_min,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpysmi,"iiIi","")
BUILTIN(__builtin_HEXAGON_M2_vcmpy_s0_sat_r,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_acc_ll_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyu_acc_ll_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_S2_asr_r_svw_trun,"iLLii","")
BUILTIN(__builtin_HEXAGON_M2_mmpyh_s0,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mmpyh_s1,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_F2_conv_sf2df,"df","")
BUILTIN(__builtin_HEXAGON_S2_vtrunohb,"iLLi","")
BUILTIN(__builtin_HEXAGON_F2_conv_sf2d_chop,"LLif","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_lh_s0,"LLiii","")
BUILTIN(__builtin_HEXAGON_F2_conv_df2w,"id","")
BUILTIN(__builtin_HEXAGON_S5_asrhub_sat,"iLLiUIi","")
BUILTIN(__builtin_HEXAGON_S2_asl_i_r_xacc,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_F2_conv_df2d,"LLid","")
BUILTIN(__builtin_HEXAGON_M2_mmaculs_s1,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mmaculs_s0,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_svadduhs,"iii","")
BUILTIN(__builtin_HEXAGON_F2_conv_sf2w_chop,"if","")
BUILTIN(__builtin_HEXAGON_S2_svsathub,"ii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_rnd_hl_s1,"LLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_rnd_hl_s0,"LLiii","")
BUILTIN(__builtin_HEXAGON_S2_setbit_r,"iii","")
BUILTIN(__builtin_HEXAGON_A2_vavghr,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_F2_sffma_sc,"ffffi","")
BUILTIN(__builtin_HEXAGON_F2_dfclass,"idUIi","")
BUILTIN(__builtin_HEXAGON_F2_conv_df2ud,"LLid","")
BUILTIN(__builtin_HEXAGON_F2_conv_df2uw,"id","")
BUILTIN(__builtin_HEXAGON_M2_cmpyrs_s0,"iii","")
BUILTIN(__builtin_HEXAGON_M2_cmpyrs_s1,"iii","")
BUILTIN(__builtin_HEXAGON_C4_cmpltei,"iiIi","")
BUILTIN(__builtin_HEXAGON_C4_cmplteu,"iii","")
BUILTIN(__builtin_HEXAGON_A2_vsubb_map,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_subh_l16_ll,"iii","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_r_rnd,"iiUIi","")
BUILTIN(__builtin_HEXAGON_M2_vrmpy_s0,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_rnd_hh_s1,"LLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_rnd_hh_s0,"LLiii","")
BUILTIN(__builtin_HEXAGON_A2_minup,"ULLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_valignrb,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_S2_asr_r_p_acc,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_M2_mmpyl_rs0,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vrcmaci_s0,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vaddub,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_combine_lh,"iii","")
BUILTIN(__builtin_HEXAGON_M5_vdmacbsu,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_combine_ll,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_hl_s0,"ULLiii","")
BUILTIN(__builtin_HEXAGON_M2_vrcmpyi_s0c,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_p_rnd,"LLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_A2_addpsat,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_svaddhs,"iii","")
BUILTIN(__builtin_HEXAGON_S4_ori_lsr_ri,"iUIiiUIi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_sat_rnd_ll_s1,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_sat_rnd_ll_s0,"iii","")
BUILTIN(__builtin_HEXAGON_A2_vminw,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vminh,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vrcmpyr_s0,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vminb,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vcmac_s0_sat_i,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_lh_s0,"ULLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_lh_s1,"ULLiii","")
BUILTIN(__builtin_HEXAGON_S2_asl_r_r_or,"iiii","")
BUILTIN(__builtin_HEXAGON_S4_lsli,"iIii","")
BUILTIN(__builtin_HEXAGON_S2_lsl_r_vw,"LLiLLii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_hh_s1,"iii","")
BUILTIN(__builtin_HEXAGON_M4_vrmpyeh_s0,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M4_vrmpyeh_s1,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_nac_lh_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_nac_lh_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_vraddh,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_C2_tfrrp,"ii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_acc_sat_ll_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_acc_sat_ll_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_S2_vtrunowh,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_abs,"ii","")
BUILTIN(__builtin_HEXAGON_A4_cmpbeq,"iii","")
BUILTIN(__builtin_HEXAGON_A2_negp,"LLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_asl_i_r_sat,"iiUIi","")
BUILTIN(__builtin_HEXAGON_A2_addh_l16_sat_hl,"iii","")
BUILTIN(__builtin_HEXAGON_S2_vsatwuh,"iLLi","")
BUILTIN(__builtin_HEXAGON_F2_dfcmpgt,"idd","")
BUILTIN(__builtin_HEXAGON_S2_svsathb,"ii","")
BUILTIN(__builtin_HEXAGON_C2_cmpgtup,"iLLiLLi","")
BUILTIN(__builtin_HEXAGON_A4_cround_ri,"iiUIi","")
BUILTIN(__builtin_HEXAGON_S4_clbpaddi,"iLLiIi","")
BUILTIN(__builtin_HEXAGON_A4_cround_rr,"iii","")
BUILTIN(__builtin_HEXAGON_C2_mux,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_dpmpyuu_s0,"ULLiii","")
BUILTIN(__builtin_HEXAGON_S2_shuffeb,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vminuw,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vaddhs,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_insert_rp,"iiiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vminuh,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vminub,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_extractu,"iiUIiUIi","")
BUILTIN(__builtin_HEXAGON_A2_svsubh,"iii","")
BUILTIN(__builtin_HEXAGON_S4_clbaddi,"iiIi","")
BUILTIN(__builtin_HEXAGON_F2_sffms,"ffff","")
BUILTIN(__builtin_HEXAGON_S2_vsxtbh,"LLii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_nac_ll_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_nac_ll_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_A2_subp,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vmpy2es_s1,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_vmpy2es_s0,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S4_parity,"iii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_acc_hh_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_acc_hh_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_S4_addi_asl_ri,"iUIiiUIi","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_nac_hh_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyd_nac_hh_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_r_nac,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_A4_cmpheqi,"iiIi","")
BUILTIN(__builtin_HEXAGON_S2_lsr_r_p_xor,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_acc_hl_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_acc_hl_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_F2_conv_sf2ud_chop,"LLif","")
BUILTIN(__builtin_HEXAGON_C2_cmpgeui,"iiUIi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_acc_sat_hh_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_acc_sat_hh_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_S2_asl_r_p_and,"LLiLLiLLii","")
BUILTIN(__builtin_HEXAGON_A2_addh_h16_sat_lh,"iii","")
BUILTIN(__builtin_HEXAGON_A2_addh_h16_sat_ll,"iii","")
BUILTIN(__builtin_HEXAGON_M4_nac_up_s1_sat,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_nac_lh_s1,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_M2_mpyud_nac_lh_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_A4_round_ri_sat,"iiUIi","")
BUILTIN(__builtin_HEXAGON_M2_mpy_nac_hl_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_nac_hl_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_A2_vavghcr,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mmacls_rs0,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_mmacls_rs1,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M2_cmaci_s0,"LLiLLiii","")
BUILTIN(__builtin_HEXAGON_S2_setbit_i,"iiUIi","")
BUILTIN(__builtin_HEXAGON_S2_asl_i_p_or,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_A4_andn,"iii","")
BUILTIN(__builtin_HEXAGON_M5_vrmpybsu,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S2_vrndpackwh,"iLLi","")
BUILTIN(__builtin_HEXAGON_M2_vcmac_s0_sat_r,"LLiLLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_vmaxuw,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_C2_bitsclr,"iii","")
BUILTIN(__builtin_HEXAGON_M2_xor_xacc,"iiii","")
BUILTIN(__builtin_HEXAGON_A4_vcmpbgtui,"iLLiUIi","")
BUILTIN(__builtin_HEXAGON_A4_ornp,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A2_tfrpi,"LLiIi","")
BUILTIN(__builtin_HEXAGON_C4_and_or,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_nac_sat_hh_s1,"iiii","")
BUILTIN(__builtin_HEXAGON_M2_mpy_nac_sat_hh_s0,"iiii","")
BUILTIN(__builtin_HEXAGON_A2_subh_h16_sat_ll,"iii","")
BUILTIN(__builtin_HEXAGON_A2_subh_h16_sat_lh,"iii","")
BUILTIN(__builtin_HEXAGON_M2_vmpy2su_s1,"LLiii","")
BUILTIN(__builtin_HEXAGON_M2_vmpy2su_s0,"LLiii","")
BUILTIN(__builtin_HEXAGON_S2_asr_i_p_acc,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_C4_nbitsclri,"iiUIi","")
BUILTIN(__builtin_HEXAGON_S2_lsr_i_vh,"LLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_S2_lsr_i_p_xacc,"LLiLLiLLiUIi","")

// V55 Scalar Instructions.

BUILTIN(__builtin_HEXAGON_A5_ACS,"LLiLLiLLiLLi","")

// V60 Scalar Instructions.

BUILTIN(__builtin_HEXAGON_S6_rol_i_p_and,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_S6_rol_i_r_xacc,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_S6_rol_i_r_and,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_S6_rol_i_r_acc,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_S6_rol_i_p_xacc,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_S6_rol_i_p,"LLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_S6_rol_i_p_nac,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_S6_rol_i_p_acc,"LLiLLiLLiUIi","")
BUILTIN(__builtin_HEXAGON_S6_rol_i_r_or,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_S6_rol_i_r,"iiUIi","")
BUILTIN(__builtin_HEXAGON_S6_rol_i_r_nac,"iiiUIi","")
BUILTIN(__builtin_HEXAGON_S6_rol_i_p_or,"LLiLLiLLiUIi","")

// V62 Scalar Instructions.

BUILTIN(__builtin_HEXAGON_S6_vtrunehb_ppp,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_V6_ldntnt0,"V16ii","")
BUILTIN(__builtin_HEXAGON_M6_vabsdiffub,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S6_vtrunohb_ppp,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_M6_vabsdiffb,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_A6_vminub_RdP,"LLiLLiLLi","")
BUILTIN(__builtin_HEXAGON_S6_vsplatrbp,"LLii","")

// V65 Scalar Instructions.

BUILTIN(__builtin_HEXAGON_A6_vcmpbeq_notany,"iLLiLLi","")

// V66 Scalar Instructions.

BUILTIN(__builtin_HEXAGON_F2_dfsub,"ddd","")
BUILTIN(__builtin_HEXAGON_F2_dfadd,"ddd","")
BUILTIN(__builtin_HEXAGON_M2_mnaci,"iiii","")
BUILTIN(__builtin_HEXAGON_S2_mask,"iUIiUIi","")

// V60 HVX Instructions.

BUILTIN(__builtin_HEXAGON_V6_veqb_or,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_veqb_or_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vminub,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vminub_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaslw_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vaslw_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyhvsrs,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyhvsrs_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsathub,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsathub_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddh_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddh_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybusi,"V32iV32iiUIi","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybusi_128B,"V64iV64iiUIi","")
BUILTIN(__builtin_HEXAGON_V6_vshufoh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vshufoh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vasrwv,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vasrwv_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhsuisat,"V16iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhsuisat_128B,"V32iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vrsadubi_acc,"V32iV32iV32iiUIi","")
BUILTIN(__builtin_HEXAGON_V6_vrsadubi_acc_128B,"V64iV64iV64iiUIi","")
BUILTIN(__builtin_HEXAGON_V6_vnavgw,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vnavgw_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vnavgh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vnavgh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vavgub,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vavgub_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubb,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubb_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgtw_and,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtw_and_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vavgubrnd,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vavgubrnd_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybusv,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybusv_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubbnq,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubbnq_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vroundhb,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vroundhb_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vadduhsat_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vadduhsat_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vsububsat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsububsat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpabus_acc,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpabus_acc_128B,"V64iV64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vmux,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmux_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyhus,"V32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyhus_128B,"V64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vpackeb,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vpackeb_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubhnq,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubhnq_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vavghrnd,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vavghrnd_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vtran2x2_map,"V16iV16iv*i","")
BUILTIN(__builtin_HEXAGON_V6_vtran2x2_map_128B,"V32iV32iv*i","")
BUILTIN(__builtin_HEXAGON_V6_vdelta,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vdelta_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgtuh_and,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtuh_and_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vtmpyhb,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vtmpyhb_128B,"V64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vpackob,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vpackob_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmaxh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmaxh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vtmpybus_acc,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vtmpybus_acc_128B,"V64iV64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vsubuhsat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubuhsat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vasrw_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasrw_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_pred_or,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_pred_or_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vrmpyub_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vrmpyub_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_lo,"V16iV32i","")
BUILTIN(__builtin_HEXAGON_V6_lo_128B,"V32iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vsubb_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubb_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vsubhsat_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubhsat_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiwh,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiwh_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiwb,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiwb_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_ldu0,"V16ii","")
BUILTIN(__builtin_HEXAGON_V6_ldu0_128B,"V32ii","")
BUILTIN(__builtin_HEXAGON_V6_vgtuh_xor,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtuh_xor_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgth_or,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgth_or_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vavgh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vavgh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vlalignb,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vlalignb_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vsh,"V32iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsh_128B,"V64iV32i","")
BUILTIN(__builtin_HEXAGON_V6_pred_and_n,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_pred_and_n_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsb,"V32iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsb_128B,"V64iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vroundwuh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vroundwuh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vasrhv,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vasrhv_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vshuffh,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vshuffh_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddhsat_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddhsat_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vnavgub,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vnavgub_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybv,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybv_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vnormamth,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vnormamth_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhb,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhb_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vavguh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vavguh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vlsrwv,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vlsrwv_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vlsrhv,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vlsrhv_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhisat,"V16iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhisat_128B,"V32iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhvsat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhvsat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddw,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddw_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vzh,"V32iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vzh_128B,"V64iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmaxub,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmaxub_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyhv_acc,"V32iV32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyhv_acc_128B,"V64iV64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vadduhsat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vadduhsat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vshufoeh,"V32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vshufoeh_128B,"V64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyuhv_acc,"V32iV32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyuhv_acc_128B,"V64iV64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_veqh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_veqh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpabuuv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpabuuv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vasrwhsat,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasrwhsat_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vminuh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vminuh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vror,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vror_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyowh_rnd_sacc,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyowh_rnd_sacc_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmaxuh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmaxuh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vabsh_sat,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vabsh_sat_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_pred_or_n,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_pred_or_n_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdealb,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vdealb_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpybusv,"V32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpybusv_128B,"V64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vzb,"V32iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vzb_128B,"V64iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdmpybus_dv,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpybus_dv_128B,"V64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vaddbq,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddbq_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddb,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddb_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddwq,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddwq_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vasrhubrndsat,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasrhubrndsat_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vasrhubsat,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasrhubsat_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vshufoeb,"V32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vshufoeb_128B,"V64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vpackhub_sat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vpackhub_sat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiwh_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiwh_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vtmpyb,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vtmpyb_128B,"V64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpabusv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpabusv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_pred_and,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_pred_and_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubwnq,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubwnq_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vpackwuh_sat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vpackwuh_sat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vswap,"V32iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vswap_128B,"V64iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vrmpyubv_acc,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vrmpyubv_acc_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgtb_and,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtb_and_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaslw,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vaslw_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vpackhb_sat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vpackhb_sat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyih_acc,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyih_acc_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vshuffvdd,"V32iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vshuffvdd_128B,"V64iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vaddb_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddb_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vunpackub,"V32iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vunpackub_128B,"V64iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgtuw,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtuw_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vlutvwh,"V32iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vlutvwh_128B,"V64iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vgtub,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtub_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyowh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyowh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyieoh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyieoh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_extractw,"iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_extractw_128B,"iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vavgwrnd,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vavgwrnd_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhsat_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhsat_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vgtub_xor,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtub_xor_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyub,"V32iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyub_128B,"V64iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyuh,"V32iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyuh_128B,"V64iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vunpackob,"V32iV32iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vunpackob_128B,"V64iV64iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpahb,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpahb_128B,"V64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_veqw_or,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_veqw_or_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vandqrt,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vandqrt_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vxor,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vxor_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vasrwhrndsat,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasrwhrndsat_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyhsat_acc,"V32iV32iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyhsat_acc_128B,"V64iV64iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybus_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybus_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vsubhw,"V32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubhw_128B,"V64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdealb4w,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vdealb4w_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyowh_sacc,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyowh_sacc_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpybv,"V32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpybv_128B,"V64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vabsdiffh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vabsdiffh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vshuffob,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vshuffob_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyub_acc,"V32iV32iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyub_acc_128B,"V64iV64iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vnormamtw,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vnormamtw_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vunpackuh,"V32iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vunpackuh_128B,"V64iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgtuh_or,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtuh_or_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiewuh_acc,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiewuh_acc_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vunpackoh,"V32iV32iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vunpackoh_128B,"V64iV64iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhsat,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhsat_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyubv,"V32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyubv_128B,"V64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyhss,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyhss_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_hi,"V16iV32i","")
BUILTIN(__builtin_HEXAGON_V6_hi_128B,"V32iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vasrwuhsat,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasrwuhsat_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_veqw,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_veqw_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdsaduh,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vdsaduh_128B,"V64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vsubw,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubw_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubw_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubw_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_veqb_and,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_veqb_and_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyih,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyih_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vtmpyb_acc,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vtmpyb_acc_128B,"V64iV64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybus,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybus_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpybus_acc,"V32iV32iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpybus_acc_128B,"V64iV64iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vgth_xor,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgth_xor_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubhsat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubhsat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vrmpyubi_acc,"V32iV32iV32iiUIi","")
BUILTIN(__builtin_HEXAGON_V6_vrmpyubi_acc_128B,"V64iV64iV64iiUIi","")
BUILTIN(__builtin_HEXAGON_V6_vabsw,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vabsw_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddwsat_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddwsat_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vlsrw,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vlsrw_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vabsh,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vabsh_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vlsrh,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vlsrh_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_valignb,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_valignb_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vsubhq,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubhq_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vpackoh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vpackoh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdmpybus_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpybus_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhvsat_acc,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhvsat_acc_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybv_acc,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybv_acc_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddhsat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddhsat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vcombine,"V32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vcombine_128B,"V64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vandqrt_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vandqrt_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vaslhv,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaslhv_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vinsertwr,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vinsertwr_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vsubh_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubh_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vshuffb,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vshuffb_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vand,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vand_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyhv,"V32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyhv_128B,"V64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhsuisat_acc,"V16iV16iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhsuisat_acc_128B,"V32iV32iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vsububsat_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsububsat_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vgtb_xor,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtb_xor_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdsaduh_acc,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vdsaduh_acc_128B,"V64iV64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vrmpyub,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vrmpyub_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyuh_acc,"V32iV32iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyuh_acc_128B,"V64iV64iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vcl0h,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vcl0h_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyhus_acc,"V32iV32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyhus_acc_128B,"V64iV64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpybv_acc,"V32iV32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpybv_acc_128B,"V64iV64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vrsadubi,"V32iV32iiUIi","")
BUILTIN(__builtin_HEXAGON_V6_vrsadubi_128B,"V64iV64iiUIi","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhb_dv_acc,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhb_dv_acc_128B,"V64iV64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vshufeh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vshufeh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyewuh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyewuh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyhsrs,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyhsrs_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpybus_dv_acc,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpybus_dv_acc_128B,"V64iV64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vaddubh,"V32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddubh_128B,"V64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vasrwh,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasrwh_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_ld0,"V16ii","")
BUILTIN(__builtin_HEXAGON_V6_ld0_128B,"V32ii","")
BUILTIN(__builtin_HEXAGON_V6_vpopcounth,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vpopcounth_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_ldnt0,"V16ii","")
BUILTIN(__builtin_HEXAGON_V6_ldnt0_128B,"V32ii","")
BUILTIN(__builtin_HEXAGON_V6_vgth_and,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgth_and_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddubsat_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddubsat_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vpackeh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vpackeh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyh,"V32iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyh_128B,"V64iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vminh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vminh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_pred_scalar2,"V16ii","")
BUILTIN(__builtin_HEXAGON_V6_pred_scalar2_128B,"V32ii","")
BUILTIN(__builtin_HEXAGON_V6_vdealh,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vdealh_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vpackwh_sat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vpackwh_sat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaslh,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vaslh_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vgtuw_and,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtuw_and_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vor,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vor_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vlutvvb,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vlutvvb_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiowh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiowh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vlutvvb_oracc,"V16iV16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vlutvvb_oracc_128B,"V32iV32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vandvrt,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vandvrt_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_veqh_xor,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_veqh_xor_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vadduhw,"V32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vadduhw_128B,"V64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vcl0w,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vcl0w_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyihb,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyihb_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vtmpybus,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vtmpybus_128B,"V64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vd0,"V16i","")
BUILTIN(__builtin_HEXAGON_V6_vd0_128B,"V32i","")
BUILTIN(__builtin_HEXAGON_V6_veqh_or,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_veqh_or_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgtw_or,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtw_or_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdmpybus,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpybus_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vgtub_or,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtub_or_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpybus,"V32iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpybus_128B,"V64iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhb_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhb_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vandvrt_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vandvrt_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vassign,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vassign_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddwnq,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddwnq_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgtub_and,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtub_and_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhb_dv,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhb_dv_128B,"V64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vunpackb,"V32iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vunpackb_128B,"V64iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vunpackh,"V32iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vunpackh_128B,"V64iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpahb_acc,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpahb_acc_128B,"V64iV64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vaddbnq,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddbnq_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vlalignbi,"V16iV16iV16iUIi","")
BUILTIN(__builtin_HEXAGON_V6_vlalignbi_128B,"V32iV32iV32iUIi","")
BUILTIN(__builtin_HEXAGON_V6_vsatwh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsatwh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgtuh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtuh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyihb_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyihb_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybusv_acc,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybusv_acc_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vrdelta,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vrdelta_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vroundwh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vroundwh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddw_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddw_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiwb_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiwb_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vsubbq,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubbq_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_veqh_and,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_veqh_and_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_valignbi,"V16iV16iV16iUIi","")
BUILTIN(__builtin_HEXAGON_V6_valignbi_128B,"V32iV32iV32iUIi","")
BUILTIN(__builtin_HEXAGON_V6_vaddwsat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddwsat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_veqw_and,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_veqw_and_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vabsdiffub,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vabsdiffub_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vshuffeb,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vshuffeb_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vabsdiffuh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vabsdiffuh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_veqw_xor,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_veqw_xor_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgth,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgth_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgtuw_xor,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtuw_xor_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgtb,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtb_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgtw,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtw_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubwq,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubwq_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vnot,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vnot_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgtb_or,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtb_or_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vgtuw_or,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtuw_or_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddubsat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddubsat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmaxw,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmaxw_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaslwv,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaslwv_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vabsw_sat,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vabsw_sat_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubwsat_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubwsat_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vroundhub,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vroundhub_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhisat_acc,"V16iV16iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhisat_acc_128B,"V32iV32iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpabus,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpabus_128B,"V64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vassignp,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vassignp_128B,"V64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_veqb,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_veqb_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsububh,"V32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsububh_128B,"V64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_lvsplatw,"V16ii","")
BUILTIN(__builtin_HEXAGON_V6_lvsplatw_128B,"V32ii","")
BUILTIN(__builtin_HEXAGON_V6_vaddhnq,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddhnq_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhsusat,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhsusat_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_pred_not,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_pred_not_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vlutvwh_oracc,"V32iV32iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vlutvwh_oracc_128B,"V64iV64iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiewh_acc,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiewh_acc_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdealvdd,"V32iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vdealvdd_128B,"V64iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vavgw,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vavgw_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhsusat_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vdmpyhsusat_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vgtw_xor,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vgtw_xor_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vtmpyhb_acc,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vtmpyhb_acc_128B,"V64iV64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vaddhw,"V32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddhw_128B,"V64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddhq,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddhq_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vrmpyubv,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vrmpyubv_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vrmpyubi,"V32iV32iiUIi","")
BUILTIN(__builtin_HEXAGON_V6_vrmpyubi_128B,"V64iV64iiUIi","")
BUILTIN(__builtin_HEXAGON_V6_vminw,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vminw_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyubv_acc,"V32iV32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyubv_acc_128B,"V64iV64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_pred_xor,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_pred_xor_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_veqb_xor,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_veqb_xor_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiewuh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiewuh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpybusv_acc,"V32iV32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpybusv_acc_128B,"V64iV64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vavguhrnd,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vavguhrnd_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyowh_rnd,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyowh_rnd_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubwsat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubwsat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubuhw,"V32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubuhw_128B,"V64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybusi_acc,"V32iV32iV32iiUIi","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybusi_acc_128B,"V64iV64iV64iiUIi","")
BUILTIN(__builtin_HEXAGON_V6_vasrw,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasrw_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vasrh,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasrh_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyuhv,"V32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyuhv_128B,"V64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vasrhbrndsat,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasrhbrndsat_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vsubuhsat_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubuhsat_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vabsdiffw,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vabsdiffw_128B,"V32iV32iV32i","")

// V62 HVX Instructions.

BUILTIN(__builtin_HEXAGON_V6_vandnqrt_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vandnqrt_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vaddclbh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddclbh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyowh_64_acc,"V32iV32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyowh_64_acc_128B,"V64iV64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyewuh_64,"V32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyewuh_64_128B,"V64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsatuwuh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsatuwuh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_shuffeqh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_shuffeqh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_shuffeqw,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_shuffeqw_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_ldcnpnt0,"V16iii","")
BUILTIN(__builtin_HEXAGON_V6_ldcnpnt0_128B,"V32iii","")
BUILTIN(__builtin_HEXAGON_V6_vsubcarry,"V16iV16iV16iv*","")
BUILTIN(__builtin_HEXAGON_V6_vsubcarry_128B,"V32iV32iV32iv*","")
BUILTIN(__builtin_HEXAGON_V6_vasrhbsat,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasrhbsat_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vminb,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vminb_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vmpauhb_acc,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpauhb_acc_128B,"V64iV64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vaddhw_acc,"V32iV32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddhw_acc_128B,"V64iV64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vlsrb,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vlsrb_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vlutvwhi,"V32iV16iV16iUIi","")
BUILTIN(__builtin_HEXAGON_V6_vlutvwhi_128B,"V64iV32iV32iUIi","")
BUILTIN(__builtin_HEXAGON_V6_vaddububb_sat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddububb_sat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubbsat_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubbsat_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_ldtp0,"V16iii","")
BUILTIN(__builtin_HEXAGON_V6_ldtp0_128B,"V32iii","")
BUILTIN(__builtin_HEXAGON_V6_vlutvvb_oracci,"V16iV16iV16iV16iUIi","")
BUILTIN(__builtin_HEXAGON_V6_vlutvvb_oracci_128B,"V32iV32iV32iV32iUIi","")
BUILTIN(__builtin_HEXAGON_V6_vsubuwsat_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsubuwsat_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_ldpnt0,"V16iii","")
BUILTIN(__builtin_HEXAGON_V6_ldpnt0_128B,"V32iii","")
BUILTIN(__builtin_HEXAGON_V6_vandvnqv,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vandvnqv_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_lvsplatb,"V16ii","")
BUILTIN(__builtin_HEXAGON_V6_lvsplatb_128B,"V32ii","")
BUILTIN(__builtin_HEXAGON_V6_lvsplath,"V16ii","")
BUILTIN(__builtin_HEXAGON_V6_lvsplath_128B,"V32ii","")
BUILTIN(__builtin_HEXAGON_V6_ldtpnt0,"V16iii","")
BUILTIN(__builtin_HEXAGON_V6_ldtpnt0_128B,"V32iii","")
BUILTIN(__builtin_HEXAGON_V6_vlutvwh_nm,"V32iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vlutvwh_nm_128B,"V64iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_ldnpnt0,"V16iii","")
BUILTIN(__builtin_HEXAGON_V6_ldnpnt0_128B,"V32iii","")
BUILTIN(__builtin_HEXAGON_V6_vmpauhb,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpauhb_128B,"V64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_ldtnp0,"V16iii","")
BUILTIN(__builtin_HEXAGON_V6_ldtnp0_128B,"V32iii","")
BUILTIN(__builtin_HEXAGON_V6_vrounduhub,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vrounduhub_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vadduhw_acc,"V32iV32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vadduhw_acc_128B,"V64iV64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_ldcp0,"V16iii","")
BUILTIN(__builtin_HEXAGON_V6_ldcp0_128B,"V32iii","")
BUILTIN(__builtin_HEXAGON_V6_vadduwsat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vadduwsat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_ldtnpnt0,"V16iii","")
BUILTIN(__builtin_HEXAGON_V6_ldtnpnt0_128B,"V32iii","")
BUILTIN(__builtin_HEXAGON_V6_vaddbsat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddbsat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vandnqrt,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vandnqrt_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiwub_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiwub_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmaxb,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vmaxb_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vandvqv,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vandvqv_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddcarry,"V16iV16iV16iv*","")
BUILTIN(__builtin_HEXAGON_V6_vaddcarry_128B,"V32iV32iV32iv*","")
BUILTIN(__builtin_HEXAGON_V6_vasrwuhrndsat,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasrwuhrndsat_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vlutvvbi,"V16iV16iV16iUIi","")
BUILTIN(__builtin_HEXAGON_V6_vlutvvbi_128B,"V32iV32iV32iUIi","")
BUILTIN(__builtin_HEXAGON_V6_vsubuwsat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubuwsat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddbsat_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddbsat_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_ldnp0,"V16iii","")
BUILTIN(__builtin_HEXAGON_V6_ldnp0_128B,"V32iii","")
BUILTIN(__builtin_HEXAGON_V6_vasruwuhrndsat,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasruwuhrndsat_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vrounduwuh,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vrounduwuh_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vlutvvb_nm,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vlutvvb_nm_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_pred_scalar2v2,"V16ii","")
BUILTIN(__builtin_HEXAGON_V6_pred_scalar2v2_128B,"V32ii","")
BUILTIN(__builtin_HEXAGON_V6_ldp0,"V16iii","")
BUILTIN(__builtin_HEXAGON_V6_ldp0_128B,"V32iii","")
BUILTIN(__builtin_HEXAGON_V6_vaddubh_acc,"V32iV32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddubh_acc_128B,"V64iV64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaddclbw,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddclbw_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_ldcpnt0,"V16iii","")
BUILTIN(__builtin_HEXAGON_V6_ldcpnt0_128B,"V32iii","")
BUILTIN(__builtin_HEXAGON_V6_vadduwsat_dv,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vadduwsat_dv_128B,"V64iV64iV64i","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiwub,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyiwub_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vsubububb_sat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubububb_sat_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_ldcnp0,"V16iii","")
BUILTIN(__builtin_HEXAGON_V6_ldcnp0_128B,"V32iii","")
BUILTIN(__builtin_HEXAGON_V6_vlutvwh_oracci,"V32iV32iV16iV16iUIi","")
BUILTIN(__builtin_HEXAGON_V6_vlutvwh_oracci_128B,"V64iV64iV32iV32iUIi","")
BUILTIN(__builtin_HEXAGON_V6_vsubbsat,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsubbsat_128B,"V32iV32iV32i","")

// V65 HVX Instructions.

BUILTIN(__builtin_HEXAGON_V6_vasruhubrndsat,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasruhubrndsat_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybub_rtt,"V32iV16iLLi","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybub_rtt_128B,"V64iV32iLLi","")
BUILTIN(__builtin_HEXAGON_V6_vmpahhsat,"V16iV16iV16iLLi","")
BUILTIN(__builtin_HEXAGON_V6_vmpahhsat_128B,"V32iV32iV32iLLi","")
BUILTIN(__builtin_HEXAGON_V6_vavguwrnd,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vavguwrnd_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vnavgb,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vnavgb_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vasrh_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasrh_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpauhuhsat,"V16iV16iV16iLLi","")
BUILTIN(__builtin_HEXAGON_V6_vmpauhuhsat_128B,"V32iV32iV32iLLi","")
BUILTIN(__builtin_HEXAGON_V6_vmpyh_acc,"V32iV32iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyh_acc_128B,"V64iV64iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybub_rtt_acc,"V32iV32iV16iLLi","")
BUILTIN(__builtin_HEXAGON_V6_vrmpybub_rtt_acc_128B,"V64iV64iV32iLLi","")
BUILTIN(__builtin_HEXAGON_V6_vavgb,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vavgb_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vaslh_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vaslh_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vavguw,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vavguw_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vlut4,"V16iV16iLLi","")
BUILTIN(__builtin_HEXAGON_V6_vlut4_128B,"V32iV32iLLi","")
BUILTIN(__builtin_HEXAGON_V6_vmpyuhe_acc,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyuhe_acc_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vrmpyub_rtt,"V32iV16iLLi","")
BUILTIN(__builtin_HEXAGON_V6_vrmpyub_rtt_128B,"V64iV32iLLi","")
BUILTIN(__builtin_HEXAGON_V6_vmpsuhuhsat,"V16iV16iV16iLLi","")
BUILTIN(__builtin_HEXAGON_V6_vmpsuhuhsat_128B,"V32iV32iV32iLLi","")
BUILTIN(__builtin_HEXAGON_V6_vasruhubsat,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasruhubsat_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyuhe,"V16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpyuhe_128B,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vrmpyub_rtt_acc,"V32iV32iV16iLLi","")
BUILTIN(__builtin_HEXAGON_V6_vrmpyub_rtt_acc_128B,"V64iV64iV32iLLi","")
BUILTIN(__builtin_HEXAGON_V6_vasruwuhsat,"V16iV16iV16ii","")
BUILTIN(__builtin_HEXAGON_V6_vasruwuhsat_128B,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpabuu_acc,"V32iV32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpabuu_acc_128B,"V64iV64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vprefixqw,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vprefixqw_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vprefixqh,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vprefixqh_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vprefixqb,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vprefixqb_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vabsb,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vabsb_128B,"V32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vavgbrnd,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vavgbrnd_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vdd0,"V32i","")
BUILTIN(__builtin_HEXAGON_V6_vdd0_128B,"V64i","")
BUILTIN(__builtin_HEXAGON_V6_vmpabuu,"V32iV32ii","")
BUILTIN(__builtin_HEXAGON_V6_vmpabuu_128B,"V64iV64ii","")
BUILTIN(__builtin_HEXAGON_V6_vabsb_sat,"V16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vabsb_sat_128B,"V32iV32i","")

// V66 HVX Instructions.

BUILTIN(__builtin_HEXAGON_V6_vaddcarrysat,"V16iV16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vaddcarrysat_128B,"V32iV32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vasr_into,"V32iV32iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vasr_into_128B,"V64iV64iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vsatdw,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vsatdw_128B,"V32iV32iV32i","")
BUILTIN(__builtin_HEXAGON_V6_vrotr,"V16iV16iV16i","")
BUILTIN(__builtin_HEXAGON_V6_vrotr_128B,"V32iV32iV32i","")

#undef BUILTIN
